#
# spec file for package python-oslo.log
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname oslo.log
Name:           python-oslo.log
Version:        3.16.0
Release:        1.2
Summary:        OpenStack log library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-oslo.config >= 3.14.0
BuildRequires:  python-oslo.context >= 2.6.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.serialization >= 1.10.0
BuildRequires:  python-oslo.utils >= 3.16.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-pyinotify >= 0.9.6
BuildRequires:  python-python-dateutil >= 2.4.2
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-six >= 1.9.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-debtcollector >= 1.2.0
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.context >= 2.6.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-pyinotify >= 0.9.6
Requires:       python-python-dateutil >= 2.4.2
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
OpenStack logging configuration library provides standardized configuration
for all openstack projects.It also provides custom formatters, handlers and
support for context specific logging (like resource id's etc).

%package doc
Summary:        Documentation for OpenStack log library
Group:          Development/Languages/Python
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
Documentation for the oslo.log library.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

# generate html docs
%{__python2} setup.py build_sphinx
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}

%check
testr init && testr run --parallel

%files
%license LICENSE
%doc ChangeLog README.rst
%{python2_sitelib}/oslo_log
%{python2_sitelib}/*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 3.16.0
  * Remove discover from test-requirements
  * Fixes unit tests on Windows
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
  * Add Python 3.5 classifier and venv
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 3.12.0
  * log: don't create foo.log
  * Improve olso.log test coverage for edge cases
  * log: Introduce _iter_loggers
  * Replace "LOG.exception(_" with "LOG.exception(_LE"
  * Make available to log encoded strings as arguments
  * Revert "Remove 'verbose' option"
  * Imported Translations from Zanata
  * Convert unicode data to utf-8 before calling syslog.syslog()
  * Provide a normal method for deprecation warnings.
  * Fix regression causing the default log level to become WARNING
  * Use new logging specific method for context info
  * Fix typo: 'Olso' to 'Oslo'
  * Reload log_config_append config on SIGHUP
  * Updated from global requirements
  * Remove 'verbose' option
  * Reduce READ_FREQ and TIMEOUT for watch-file
* Tue May 31 2016 tbechtold@suse.com
- update to 3.7.0:
  * Fix example issue
  * Updated from global requirements
  * Allow reload of 'debug' option
  * Imported Translations from Zanata
  * Remove direct dependency on babel
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Remove outdated comment in ContextFormatter
  * Enable log_method_call to work on static method
  * Explicitly exclude tests from bandit scan
  * Improve test code coverage of _options
  * Update reno for stable/mitaka
  * Unit test cleanup and validation improvements
  * Added +2 release names for versionutils
  * Fix broken links in docs usage page
  * Enable bandit in gate
  * Updated from global requirements
- Use renderspec service to update .spec file
* Mon Mar 14 2016 tbechtold@suse.com
- update to 3.2.0:
  * use log.warning instead of log.warn
  * Imported Translations from Zanata
  * Updated from global requirements
  * Remove deprecated use-syslog-rfc-format option
  * Add release note for removed log_format option
  * Updated from global requirements
  * add page for release notes for unreleased versions
  * add a release note about using reno
  * Add reno for release notes management
  * remove pypy from default tox environment list
  * stop making a copy of options discovered by config generator
  * always run coverage report
  * Remove bandit.yaml in favor of defaults
  * Updated from global requirements
  * Fix spell typos
  * set oslo.cache and dogpile to INFO
  * Update translation setup
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Improve Logging docs with inline examples and context example
  * Revert "Pass environment variables of proxy to tox"
  * Clean up removed hacking rule from [flake8] ignore lists
  * Provide a deprecated_reason for use_syslog_rfc_format
  * Remove deprecated log-format option
  * Improve documentataion of Oslo Log Usage
  * Added public method to getting default log levels
  * Updated from global requirements
  * enable isotime for exceptions
  * assertIsNone(val) instead of assertEqual(None,val)
- Adjust Requires
* Mon Jan  4 2016 dmueller@suse.com
- update to 2.2.0:
  * Set keystoneauth default log level to WARN
  * Format record before passing it to syslog
  * Updated from global requirements
  * Updated from global requirements
  * Remove iso8601 dependency
  * Remove duplicated profiles section from bandit.yaml
  * test_logging_error: build a logger at the test level
  * Cleanup all handlers in _setup_logging_from_conf
  * Drop python 2.6 support
  * Add a 'bandit' target to tox.ini
  * Updated from global requirements
  * Log to sys.stderr to avoid "No handlers could be found..."
  * Remove python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Refactor Python 2.6 check to use constant
  * The user_identity format flexibility
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Allow oslo.log to work on non-linux platforms
* Mon Nov 16 2015 bwiedemann@suse.com
- update to 1.12.0:
  * Fix coverage configuration and execution
  * No need for Oslo Incubator Sync
  * Imported Translations from Zanata
  * Fix unintended assignment of "syslog"
  * Make doc title consistent with readme
  * add documentation with example of an external configuration file
  * add auto-generated docs for config options
  * Update option docs for when log config is used
  * Updated from global requirements
  * Add optional 'fixture' dependencies
  * Change ignore-errors to ignore_errors
  * Fix the home-page value in setup.cfg with openstack.org
  * FastWatchedFileHandler class was added
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.11.0:
  * Fix poor examples of exception logging
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Thu Aug 27 2015 tbechtold@suse.com
- update to 1.10.0:
  * Fix package name for PublishErrorsHandler
  * Updated from global requirements
  * Fix duplicate-key pylint issue
  * Maintain old oslo logger names
  * Add Mitaka release to versionutils
  * Update single letter release names to full names
  * Provide a way to register versionutils options
  * Imported Translations from Transifex
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Wed Aug  5 2015 tbechtold@suse.com
- update to 1.8.0:
  * Set verbose to True and deprecate it
  * Define TRACE logging level
  * Imported Translations from Transifex
  * Updated from global requirements
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Tue Jul 28 2015 tbechtold@suse.com
- update to 1.7.0:
  * Imported Translations from Transifex
  * Add more default fancier formatting params
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Do not report deprecations in subclasses
  * Imported Translations from Transifex
  * Updated from global requirements
  * Add tox target to find missing requirements
- update Requires according to requirements.txt
* Sun Jul 19 2015 dmueller@suse.com
- update to 1.6.0:
  * Remove duplication of fatal_deprecations option
  * Imported Translations from Transifex
* Wed Jun 24 2015 tbechtold@suse.com
- update to 1.5.0:
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * Deprecate use-syslog-rfc-format for removal
* Wed Jun 10 2015 tbechtold@suse.com
- update to 1.4.0:
  * just version bump. no other changes
* Tue Jun  2 2015 tbechtold@suse.com
- update to 1.3.0:
  * Do not fail if syslog is not available
  * Use proper deprecation for use-syslog-rfc-format option
  * Replace RFCSysLogHandler by a syslog() based one
  * Make remove_in=0 (no removal) use a better syntax
  * Remove is_compatible from versionutils
  * Add versionutils options to list_opts
  * Add versionutils to API documentation
  * Advertise support for Python3.4 / Remove support for Python 3.3
  * Updated from global requirements
  * Updated from global requirements
  * Remove run_cross_tests.sh
  * Deprecate WritableLogger - used for eventlet logging
  * Log deprecation message when catching deprecated exceptions
  * Change misleading TRACE to ERROR
  * Uncap library requirements for liberty
  * Provide an API to let tempest control the log file
  * fix pep8 errors
  * Add pypi download + version badges
  * Update to latest hacking
  * Add link to Logging Guidelines
  * move versionutils into place
  * Add liberty release name to versionutils
  * Expose opts entry point for version_utils
  * Switch from oslo.config to oslo_config
  * Remove oslo.log code and clean up versionutils API
  * Remove code that moved to oslo.i18n
  * Enhance versionutils.deprecated to work with classes
  * Add Kilo release name to versionutils
  * Allow deprecated decorator to specify no plan for removal
  * Add JUNO as a target to versionutils module
  * pep8: fixed multiple violations
  * Use oslotest instead of common test module
  * Use hacking import_exceptions for gettextutils._
  * fixed typos
  * Fix violations of H302:import only modules
  * Adds decorator to deprecate functions and methods
  * Remove vim header
  * Add `versionutils` for version compatibility checks
  * Default to True for use-syslog-rfc-format
  * Updated from global requirements
  * Restore automatic unicode conversion
  * Add migration notes
- Adjust Requires according to requirements.txt
* Wed Apr 22 2015 tbechtold@suse.com
- Add missing BuildRequires and enable testsuite
* Wed Apr 22 2015 tbechtold@suse.com
- Remove python-discover from BuildRequires. We no longer care
  about python < 2.7 versions.
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.0.0:
  * Updated from global requirements
  * Pickup instance from log format record
  * Make use_syslog=True log to syslog via /dev/log
- update Requires according to requirements.txt
* Tue Feb 24 2015 tbechtold@suse.com
- update to version 0.3.0:
  * Updated from global requirements
- Update Requires
* Thu Feb  5 2015 tbechtold@suse.com
- update to version 0.2.0:
  * Expose fixtures through oslo_log.fixture
  * Add fixture to let tests change log levels
  * Rename logging fixture module
  * Update comment to match implementation
  * fix link to bug tracker in readme
  * Updated from global requirements
- Update Requires
* Fri Jan 23 2015 tbechtold@suse.com
- Adjust Requires versions
* Fri Jan 23 2015 tbechtold@suse.com
- Initial packaging
